==> django_admin_data_views-0.4.0.tar.gz: django_admin_data_views-0.4.0/admin_data_views/admin.py <==
from __future__ import annotations

import json
from typing import TYPE_CHECKING

from django.contrib import admin
from django.http import HttpRequest, HttpResponse
from django.template.response import TemplateResponse
from django.urls import URLPattern, URLResolver, path
from django.utils.translation import gettext

from .settings import admin_data_settings

if TYPE_CHECKING:
    from .typing import Any, AppDict, AppModel, Callable

__all__ = [
    "add_url",
    "get_data_admin_views",
]


def add_url(baseroute: str, route: str, name: str) -> AppModel:
    return {
        "name": " ".join([val.capitalize() for val in name.split("_")]),
        "object_name": name.lower(),
        "perms": {"add": False, "change": False, "delete": False, "view": True},
        "admin_url": f"/admin/{baseroute}/{route}/",
        "add_url": None,
        "view_only": True,
    }


def get_data_admin_views() -> AppDict:
    baseroute = admin_data_settings.NAME.lower().replace(" ", "-")
    return {
        "name": admin_data_settings.NAME,
        "app_label": baseroute,
        "app_url": f"/admin/{baseroute}/",
        "has_module_perms": True,
        "models": [
            add_url(baseroute=baseroute, route=item["route"], name=item["name"]) for item in admin_data_settings.URLS
        ],
    }


def download_file(request: HttpRequest) -> HttpResponse:  # pragma: no cover
    if request.method.upper() != "POST":
        return HttpResponse(
            status=405,
            content=f"{request.method} not supported.",
            headers={"Allow": "POST"},
        )

    try:
        name: str = request.POST["name"]  # type: ignore[assignment]
    except KeyError:
        return HttpResponse(status=400, content="'name' is required.")

    try:
        data: str = request.POST["data"]  # type: ignore[assignment]
        data = json.dumps(json.loads(data), indent=2)
    except KeyError:
        return HttpResponse(status=400, content="'data' is required.")
    except Exception:  # noqa: BLE001
        return HttpResponse(status=400, content="'data' is is not valid json.")

    response = HttpResponse(content_type="application/force-download")
    response["Content-Disposition"] = f'attachment; filename="{name}.json"'
    response.write(data)
    return response


# Added to site


def get_app_list(self: admin.AdminSite, request: HttpRequest, *args: Any) -> list[AppDict]:
    baseroute = admin_data_settings.NAME.lower().replace(" ", "-")
    app_dict = self._build_app_dict(request, *args) or {}  # pylint: disable=protected-access

    if baseroute not in app_dict and admin_data_settings.NAME in args:
        app_dict = {baseroute: app_dict}

    if not args or admin_data_settings.NAME in args:
        data_admin_views = get_data_admin_views()

        # Extend models in an already existing app
        if baseroute in app_dict and "models" in app_dict[baseroute]:
            app_dict[baseroute]["models"].extend(data_admin_views["models"])  # pragma: no cover
        else:
            app_dict[baseroute] = data_admin_views

    if admin_data_settings.NAME in args:
        app_dict = {baseroute: app_dict[baseroute]}

    # Sort the apps alphabetically.
    app_list = sorted(app_dict.values(), key=lambda x: x["name"].lower())

    # Sort the models alphabetically within each app.
    for app in app_list:
        app["models"].sort(key=lambda x: x["name"])

    return app_list


def admin_data_index_view(self: admin.AdminSite, request: HttpRequest, **kwargs: Any) -> TemplateResponse:
    app_list = self.get_app_list(request, admin_data_settings.NAME)
    context = {
        "title": gettext("%(app)s administration") % {"app": app_list[0]["name"]},
        "subtitle": None,
        "app_list": app_list,
        "app_label": admin_data_settings.NAME,
    }
    context.update(self.each_context(request))
    context.update(kwargs.get("extra_context", {}))

    request.current_app = admin_data_settings.NAME
    return TemplateResponse(request, "admin/app_index.html", context)


def get_admin_data_urls(self: admin.AdminSite) -> list[URLResolver | URLPattern]:
    baseroute = admin_data_settings.NAME.lower().replace(" ", "-")
    custom_paths = [
        path(
            route=f"{baseroute}/",
            view=self.admin_view(self.admin_data_index_view),
            name="admin-data-index-view",
        ),
        path(
            route=f"{baseroute}/download/",
            view=self.admin_view(download_file),
            name="admin-data-download",
        ),
    ]
    for item in admin_data_settings.URLS:
        custom_paths.append(
            path(
                route=f"{baseroute}/{item['route']}/",
                view=self.admin_view(item["view"]),
                name=item["name"],
            )
        )
        if item["items"] is not None:
            custom_paths.append(
                path(
                    route=f"{baseroute}/{item['route']}/{item['items']['route']}/",
                    view=self.admin_view(item["items"]["view"]),
                    name=item["items"]["name"],
                )
            )

    return custom_paths


def get_urls(
    original_get_urls: Callable[[], list[URLResolver | URLPattern]],
) -> Callable[[admin.AdminSite], list[URLResolver | URLPattern]]:
    def get_urls_inner(self: admin.AdminSite) -> list[URLResolver | URLPattern]:
        return self.get_admin_data_urls() + original_get_urls()

    return get_urls_inner


# Patch the admin site object with data admin view methods
# pylint: disable=no-value-for-parameter
admin.site.get_app_list = get_app_list.__get__(admin.site, admin.AdminSite)
admin.site.admin_data_index_view = admin_data_index_view.__get__(admin.site, admin.AdminSite)
admin.site.get_admin_data_urls = get_admin_data_urls.__get__(admin.site, admin.AdminSite)
admin.site.get_urls = get_urls(admin.site.get_urls).__get__(admin.site, admin.AdminSite)

==> django_admin_data_views-0.4.1.tar.gz: django_admin_data_views-0.4.1/admin_data_views/admin.py <==
from __future__ import annotations

import json
from typing import TYPE_CHECKING

from django.contrib import admin
from django.http import HttpRequest, HttpResponse
from django.template.response import TemplateResponse
from django.urls import URLPattern, URLResolver, path
from django.utils.translation import gettext

from .settings import admin_data_settings

if TYPE_CHECKING:
    from .typing import Any, AppDict, AppModel, Callable

__all__ = [
    "add_url",
    "get_data_admin_views",
]


def add_url(baseroute: str, route: str, name: str) -> AppModel:
    return {
        "name": " ".join([val.capitalize() for val in name.split("_")]),
        "object_name": name.lower(),
        "perms": {"add": False, "change": False, "delete": False, "view": True},
        "admin_url": f"/admin/{baseroute}/{route}/",
        "add_url": None,
        "view_only": True,
    }


def get_data_admin_views() -> AppDict:
    baseroute = admin_data_settings.NAME.lower().replace(" ", "-")
    return {
        "name": admin_data_settings.NAME,
        "app_label": baseroute,
        "app_url": f"/admin/{baseroute}/",
        "has_module_perms": True,
        "models": [
            add_url(baseroute=baseroute, route=item["route"], name=item["name"]) for item in admin_data_settings.URLS
        ],
    }


def download_json(request: HttpRequest) -> HttpResponse:  # pragma: no cover
    if request.method.upper() != "POST":
        return HttpResponse(
            status=405,
            content=f"{request.method} not supported.",
            headers={"Allow": "POST"},
        )

    try:
        name: str = request.POST["name"]  # type: ignore[assignment]
    except KeyError:
        return HttpResponse(status=400, content="'name' is required.")

    try:
        data: str = request.POST["data"]  # type: ignore[assignment]
        data = json.dumps(json.loads(data), indent=2)
    except KeyError:
        return HttpResponse(status=400, content="'data' is required.")
    except Exception:  # noqa: BLE001
        return HttpResponse(status=400, content="'data' is is not valid json.")

    response = HttpResponse(content_type="application/force-download")
    response["Content-Disposition"] = f'attachment; filename="{name}.json"'
    response.write(data)
    return response


def download_csv(request: HttpRequest) -> HttpResponse:  # pragma: no cover
    if request.method.upper() != "POST":
        return HttpResponse(
            status=405,
            content=f"{request.method} not supported.",
            headers={"Allow": "POST"},
        )

    try:
        name: str = request.POST["name"]  # type: ignore[assignment]
    except KeyError:
        return HttpResponse(status=400, content="'name' is required.")

    try:
        data: str = request.POST["data"]  # type: ignore[assignment]
    except KeyError:
        return HttpResponse(status=400, content="'data' is required.")

    response = HttpResponse(content_type="application/force-download")
    response["Content-Disposition"] = f'attachment; filename="{name}.csv"'
    response.write(data)
    return response


# Added to site


def get_app_list(self: admin.AdminSite, request: HttpRequest, *args: Any) -> list[AppDict]:
    baseroute = admin_data_settings.NAME.lower().replace(" ", "-")
    app_dict = self._build_app_dict(request, *args) or {}  # pylint: disable=protected-access

    if baseroute not in app_dict and admin_data_settings.NAME in args:
        app_dict = {baseroute: app_dict}

    if not args or admin_data_settings.NAME in args:
        data_admin_views = get_data_admin_views()

        # Extend models in an already existing app
        if baseroute in app_dict and "models" in app_dict[baseroute]:
            app_dict[baseroute]["models"].extend(data_admin_views["models"])  # pragma: no cover
        else:
            app_dict[baseroute] = data_admin_views

    if admin_data_settings.NAME in args:
        app_dict = {baseroute: app_dict[baseroute]}

    # Sort the apps alphabetically.
    app_list = sorted(app_dict.values(), key=lambda x: x["name"].lower())

    # Sort the models alphabetically within each app.
    for app in app_list:
        app["models"].sort(key=lambda x: x["name"])

    return app_list


def admin_data_index_view(self: admin.AdminSite, request: HttpRequest, **kwargs: Any) -> TemplateResponse:
    app_list = self.get_app_list(request, admin_data_settings.NAME)
    context = {
        "title": gettext("%(app)s administration") % {"app": app_list[0]["name"]},
        "subtitle": None,
        "app_list": app_list,
        "app_label": admin_data_settings.NAME,
    }
    context.update(self.each_context(request))
    context.update(kwargs.get("extra_context", {}))

    request.current_app = admin_data_settings.NAME
    return TemplateResponse(request, "admin/app_index.html", context)


def get_admin_data_urls(self: admin.AdminSite) -> list[URLResolver | URLPattern]:
    baseroute = admin_data_settings.NAME.lower().replace(" ", "-")
    custom_paths = [
        path(
            route=f"{baseroute}/",
            view=self.admin_view(self.admin_data_index_view),
            name="admin-data-index-view",
        ),
        path(
            route=f"{baseroute}/download/json/",
            view=self.admin_view(download_json),
            name="admin-json-download",
        ),
        path(
            route=f"{baseroute}/download/csv/",
            view=self.admin_view(download_csv),
            name="admin-csv-download",
        ),
    ]
    for item in admin_data_settings.URLS:
        custom_paths.append(
            path(
                route=f"{baseroute}/{item['route']}/",
                view=self.admin_view(item["view"]),
                name=item["name"],
            )
        )
        if item["items"] is not None:
            custom_paths.append(
                path(
                    route=f"{baseroute}/{item['route']}/{item['items']['route']}/",
                    view=self.admin_view(item["items"]["view"]),
                    name=item["items"]["name"],
                )
            )

    return custom_paths


def get_urls(
    original_get_urls: Callable[[], list[URLResolver | URLPattern]],
) -> Callable[[admin.AdminSite], list[URLResolver | URLPattern]]:
    def get_urls_inner(self: admin.AdminSite) -> list[URLResolver | URLPattern]:
        return self.get_admin_data_urls() + original_get_urls()

    return get_urls_inner


# Patch the admin site object with data admin view methods
# pylint: disable=no-value-for-parameter
admin.site.get_app_list = get_app_list.__get__(admin.site, admin.AdminSite)
admin.site.admin_data_index_view = admin_data_index_view.__get__(admin.site, admin.AdminSite)
admin.site.get_admin_data_urls = get_admin_data_urls.__get__(admin.site, admin.AdminSite)
admin.site.get_urls = get_urls(admin.site.get_urls).__get__(admin.site, admin.AdminSite)
